@@ -12,3 +12,10 @@ class FancyBoxImagePluginForm(forms.ModelForm):
     class Meta:
         model = FancyBoxPlugin
         exclude = ('popup_text',)
+        
+class FancyBoxSnippetPluginForm(forms.ModelForm):
+    popup_text = forms.CharField(label="HTML Snippet", widget=forms.Textarea)
+    class Meta:
+        model = FancyBoxPlugin
+        exclude = ('target_image', 'target_image_height', 'target_image_width', 'target_image_title',)
+
